# Generated by Django 5.0.2 on 2024-02-17 00:43

import encrypted_model_fields.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('translator', '0009_deepltranslator_proxy_deepltranslator_server_url'),
    ]

    operations = [
        migrations.CreateModel(
            name='ClaudeTranslator',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='Name')),
                ('valid', models.BooleanField(null=True, verbose_name='Valid')),
                ('model', models.CharField(
                    choices=[('claude-instant-1.2', 'claude-instant-1.2'), ('claude-2.1', 'claude-2.1'),
                             ('claude-2.0', 'claude-2.0')], default='claude-instant-1.2', max_length=50)),
                ('api_key', encrypted_model_fields.fields.EncryptedCharField(verbose_name='API Key')),
                ('max_tokens', models.IntegerField(default=1000)),
                ('base_url', models.URLField(default='https://api.anthropic.com', verbose_name='API URL')),
                ('prompt', models.TextField(
                    default='Translate only the text from the following into {target_language},only returns translations.\n{text}')),
                ('proxy', models.URLField(blank=True, default=None, null=True, verbose_name='Proxy(optional)')),
                ('temperature', models.FloatField(default=0.7)),
                ('top_p', models.FloatField(blank=True, default=0.7, null=True)),
                ('top_k', models.IntegerField(default=1)),
            ],
            options={
                'verbose_name': 'Anthropic Claude',
                'verbose_name_plural': 'Anthropic Claude',
            },
        ),
    ]
