from .base import TranslatorEngine, Translated_Content
from .azureai import AzureAITranslator
from .caiyun import CaiYunTranslator
from .claude import ClaudeTranslator
from .deepl import DeepLTranslator
from .deeplx import DeepLXTranslator
from .deeplweb import DeepLWebTranslator
from .gemini import GeminiTranslator
from .google_translate_web import GoogleTranslateWebTranslator
from .microsoft_translate import MicrosoftTranslator
from .moonshotai import MoonshotAITranslator
from .openai import OpenAITranslator
from .dev import TestTranslator
